//! # Implementation of the OCPP 2.0.1 Specification
//!
//! ## Messages, Datatypes & Enumerations
//!
//! The following modules implements all messages, datatypes and enumerations
//! of the ocpp 2.0.1 specification
//!

/// datatypes
pub mod datatypes;

/// enumerations
pub mod enumerations;

/// messages
pub mod messages;

/// helper functions
pub mod helpers;
